@@ -41,6 +41,7 @@ class ProgressBar:
             self.enums = items
         else:
             self.items = items
+            self.enums = None
         self.maxlen = maxlen
         self.pos = 0
         self.char = char
@@ -74,9 +75,13 @@ class ProgressBar:
         return self.completed / other
 
     def __iter__(self):
-        for i in range(self.items):
-            self.update()
-            yield self.enums[i]
+        if self.enums:
+            for i in self.enums:
+                self.update()
+                yield i
+        else:
+            while True:
+                yield next(self.items)
 
     def __iadd__(self, other):
         self.update(other)
